@@ -11,7 +11,7 @@
 #
 # This Source Code Form is subject to the terms of the Mozilla Public License,
 # v. 2.0. If a copy of the MPL was not distributed with this file, You can
-# obtain one at http://mozilla.org/MPL/2.0/.
+# obtain one at https://mozilla.org/MPL/2.0/.
 #
 # END HEADER
 
@@ -39,7 +39,6 @@ from hypothesis._settings import (
     Verbosity,
     note_deprecation,
     settings as Settings,
-    unlimited,
 )
 from hypothesis.control import current_build_context
 from hypothesis.core import given
@@ -83,11 +82,7 @@ def run_state_machine_as_test(state_machine_factory, settings=None):
             settings = state_machine_factory.TestCase.settings
             check_type(Settings, settings, "state_machine_factory.TestCase.settings")
         except AttributeError:
-            settings = Settings(
-                timeout=unlimited,
-                deadline=None,
-                suppress_health_check=HealthCheck.all(),
-            )
+            settings = Settings(deadline=None, suppress_health_check=HealthCheck.all())
     check_type(Settings, settings, "settings")
 
     @settings
@@ -229,11 +224,7 @@ class GenericStateMachine(
             pass
 
         class StateMachineTestCase(TestCase):
-            settings = Settings(
-                timeout=unlimited,
-                deadline=None,
-                suppress_health_check=HealthCheck.all(),
-            )
+            settings = Settings(deadline=None, suppress_health_check=HealthCheck.all())
 
         # We define this outside of the class and assign it because you can't
         # assign attributes to instance method values in Python 2
@@ -331,6 +322,21 @@ def consumes(bundle):
     return BundleConsumer(bundle)
 
 
+@attr.s()
+class MultipleResults(object):
+    values = attr.ib()
+
+
+def multiple(*args):
+    """This function can be used to pass multiple results to the target(s) of
+    a rule. Just use ``return multiple(result1, result2, ...)`` in your rule.
+
+    It is also possible to use ``return multiple()`` with no arguments in
+    order to end a rule without passing any result.
+    """
+    return MultipleResults(args)
+
+
 def _convert_targets(targets, target):
     """Single validator and convertor for target arguments."""
     if target is not None:
@@ -795,6 +801,15 @@ class RuleBasedStateMachine(GenericStateMachine):
             )
         )
 
+    def _add_result_to_targets(self, targets, result):
+        name = self.new_name()
+        self.__printer.singleton_pprinters.setdefault(
+            id(result), lambda obj, p, cycle: p.text(name)
+        )
+        self.names_to_values[name] = result
+        for target in targets:
+            self.bundle(target).append(VarReference(name))
+
     def execute_step(self, step):
         rule, data = step
         data = dict(data)
@@ -803,13 +818,11 @@ class RuleBasedStateMachine(GenericStateMachine):
                 data[k] = self.names_to_values[v.name]
         result = rule.function(self, **data)
         if rule.targets:
-            name = self.new_name()
-            self.names_to_values[name] = result
-            self.__printer.singleton_pprinters.setdefault(
-                id(result), lambda obj, p, cycle: p.text(name)
-            )
-            for target in rule.targets:
-                self.bundle(target).append(VarReference(name))
+            if isinstance(result, MultipleResults):
+                for single_result in result.values:
+                    self._add_result_to_targets(rule.targets, single_result)
+            else:
+                self._add_result_to_targets(rule.targets, result)
         if self._initialize_rules_to_run:
             self._initialize_rules_to_run.remove(rule)
 
